<?php

namespace Drupal\tome_base;

use Symfony\Component\Console\Input\InputInterface;

/**
 * Contains methods useful for finding the current executable.
 */
trait ExecutableFinderTrait {

  /**
   * Finds an executable string for the current process.
   *
   * @param \Symfony\Component\Console\Input\InputInterface $input
   *   The command input.
   *
   * @return string
   *   An executable string, i.e. "drush @foo.bar" or "./vendor/bin/drupal".
   */
  protected function findExecutable(InputInterface $input) {
    $args = [];
    foreach ($_SERVER['argv'] as $arg) {
      if ($arg === $input->getFirstArgument()) {
        break;
      }
      if (strpos($arg, '--backend') !== 0) {
        $args[] = $arg;
      }
    }
    return implode(' ', $args);
  }

}
